@@ -1,5 +1,5 @@
 package Dependency::Resolver::Node;
-$Dependency::Resolver::Node::VERSION = '0.02';
+$Dependency::Resolver::Node::VERSION = '0.03';
 use utf8;
 use Moose;
 
@@ -28,7 +28,7 @@ Dependency::Resolver::Node - Dependency resolver node
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -48,8 +48,13 @@ $c->addEdge($e);    # c depends on e
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new( name => '...')
+
 =head2 addEdge($edge)
 
+# node A depnds on nodeB
+$nodeA->addEdge($nodeB);
+
 =head1 AUTHOR
 
 Daniel Brosseau, C<< <dab at catapulse.org> >>
